==============
ProxySQL Tools
==============


.. image:: https://img.shields.io/pypi/v/proxysql_tools.svg
        :target: https://pypi.python.org/pypi/proxysql_tools

.. image:: https://travis-ci.org/twindb/proxysql-tools.svg
        :target: https://travis-ci.org/twindb/proxysql-tools

.. image:: https://img.shields.io/codecov/c/github/twindb/proxysql-tools.svg
        :target: https://codecov.io/gh/twindb/proxysql-tools

.. image:: https://readthedocs.org/projects/proxysql-tools/badge/?version=master
        :target: https://proxysql-tools.readthedocs.io
        :alt: Documentation Status



ProxySQL Tools


* Free software: Apache Software License 2.0
* Documentation: https://proxysql-tools.readthedocs.io.


Features
--------

* ProxySQL on AWS support
* ProxySQL and Percona XtraDB Cluster integration
* ProxySQL scheduler

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

